﻿//
// Copyright (c) 2012, MindFusion LLC - Bulgaria.
//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Text;
using System.Windows.Forms;

using SolidBrush = MindFusion.Drawing.SolidBrush;
using MindFusion.Drawing;
using MindFusion.Diagramming;
using MindFusion.Diagramming.Layout;


namespace MindFusion.Diagramming.WinForms.Samples.CS.AnnealLayout
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();

			diagramView1.Diagram.ShapeNodeStyle.Brush = new LinearGradientBrush(
                Color.FromArgb(192, 192, 192), Color.FromArgb(97, 106, 127), 5);
            diagramView1.Diagram.BackBrush = new MindFusion.Drawing.SolidBrush(Color.FromArgb(224, 233, 233));
            diagramView1.Diagram.BackBrush = new MindFusion.Drawing.SolidBrush(Color.FromArgb(224, 233, 233));

			diagramView1.Diagram.DefaultShape = Shapes.Ellipse;

			MindFusion.Diagramming.Layout.AnnealLayout _layout =
				new MindFusion.Diagramming.Layout.AnnealLayout();
		
			iterationTxB.Text = _layout.IterationsPerStage.ToString();
			stageTxB.Text = _layout.Stages.ToString();
			initialTxB.Text = _layout.InitialTemperature.ToString();
			tempScaleTxB.Text = _layout.TemperatureScale.ToString();

			arrowLengthFactorTxB.Text = _layout.LinkLengthFactor.ToString();
			crossingArrowsCostTxB.Text = _layout.CrossingLinksCost.ToString();
			distributionFactorTxB.Text = _layout.DistributionFactor.ToString();
			nodeArrowDistFactorTxB.Text = _layout.NodeLinkDistFactor.ToString();
			boundaryFactorTxB.Text = _layout.BoundaryFactor.ToString();

			try
			{
				FileInfo file = new FileInfo(@"AnnealLayout");
				diagramView1.Diagram.LoadFromFile(file.Name);
			}
			catch (FileLoadException exp)
			{
				MessageBox.Show(exp.Message);
				return;
			}
			catch (Exception exp)
			{
				MessageBox.Show(exp.Message);
			}
		}

		private void layoutBtn_Click(object sender, EventArgs e)
		{
			MindFusion.Diagramming.Layout.AnnealLayout layout =
				new MindFusion.Diagramming.Layout.AnnealLayout();

			int initIter;
			int initStages;
			double initTemp;
			double initTempScale;
			double arrowLengthFactor;
			double crossingArrowsCost;
			double distributionFactor;
			double nodeArrowDistFactor;
			double boundaryFactor;

			String errorValue = "";

			try
			{
				errorValue = iterationTxB.Text;
				initIter = Int32.Parse(iterationTxB.Text);
				errorValue = stageTxB.Text;
				initStages = Int32.Parse(stageTxB.Text);
				errorValue = initialTxB.Text;
				initTemp = Double.Parse(initialTxB.Text);
				errorValue = tempScaleTxB.Text;
				initTempScale = Double.Parse(tempScaleTxB.Text);

				errorValue = arrowLengthFactorTxB.Text;
				arrowLengthFactor = Double.Parse(arrowLengthFactorTxB.Text);
				errorValue = crossingArrowsCostTxB.Text;
				crossingArrowsCost = Double.Parse(crossingArrowsCostTxB.Text);
				errorValue = distributionFactorTxB.Text;
				distributionFactor = Double.Parse(distributionFactorTxB.Text);
				errorValue = nodeArrowDistFactorTxB.Text;
				nodeArrowDistFactor = Double.Parse(nodeArrowDistFactorTxB.Text);
				errorValue = boundaryFactorTxB.Text;
				boundaryFactor = Double.Parse(boundaryFactorTxB.Text);
			
			}
			catch
			{
				MessageBox.Show( 
					"Error! Incorrect input: " + errorValue);
				return;
			}

			layout.IterationsPerStage = initIter;
			layout.Stages = initStages;
			layout.InitialTemperature = initTemp;
			layout.TemperatureScale = initTempScale;

			layout.LinkLengthFactor = arrowLengthFactor;
			layout.CrossingLinksCost = crossingArrowsCost;
			layout.DistributionFactor = distributionFactor;
			layout.NodeLinkDistFactor = nodeArrowDistFactor;
			layout.BoundaryFactor = boundaryFactor;

			layout.Arrange(diagramView1.Diagram);
			diagramView1.Diagram.ResizeToFitItems(10);
		}

		private void loadBtn_Click(object sender, EventArgs e)
		{
			OpenFileDialog dlg = new OpenFileDialog();

			if (dlg.ShowDialog() == DialogResult.OK)
				diagramView1.Diagram.LoadFromFile(dlg.FileName);
		}

		private void saveBtn_Click(object sender, EventArgs e)
		{
			SaveFileDialog dlg = new SaveFileDialog();

			if (dlg.ShowDialog() == DialogResult.OK)
				diagramView1.Diagram.SaveToFile(dlg.FileName);
		}

		private void importBtn_Click(object sender, EventArgs e)
		{
			OpenFileDialog dlg = new OpenFileDialog();
			dlg.Title = "Import";

			if (dlg.ShowDialog() == DialogResult.OK)
				diagramView1.Diagram.LoadFromXml(dlg.FileName);
		}

		private void exportBtn_Click(object sender, EventArgs e)
		{
			SaveFileDialog dlg = new SaveFileDialog();
			dlg.Title = "Export";

			if (dlg.ShowDialog() == DialogResult.OK)
				diagramView1.Diagram.SaveToXml(dlg.FileName);
		}
	}
}